DitoNotificationOptions class

Constructors

DitoNotificationOptions({int? accentColor, int? largeIconResId, int? smallIconResId, String? soundResourceName})
const

Properties

accentColor int?
final
hashCode int
The hash code for this object.
no setterinherited
largeIconResId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallIconResId int?
final
soundResourceName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited