- Inheritance
-
- Object
- PlatformInterface
- DitoSdkPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getNotifications()
→ Future<List<DitoNotificationInfo>>
-
-
getPlatformVersion()
→ Future<String?>
-
-
handleNotificationClick(Map<String, dynamic> userInfo)
→ Future<bool>
-
-
handleNotificationReceived(Map<String, dynamic> userInfo)
→ Future<bool>
-
-
identify({required String id, String? name, String? email, Map<String, dynamic>? customData})
→ Future<void>
-
-
initialize({required String appKey, required String appSecret})
→ Future<void>
-
-
initializeWithApiKey({required String apiKey, required String bundleId})
→ Future<void>
-
-
markNotificationAsRead(String id)
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
registerDeviceToken(String token)
→ Future<void>
-
-
setDebugMode({required bool enabled})
→ Future<void>
-
-
setNotificationOptions(DitoNotificationOptions options)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
track({required String action, Map<String, dynamic>? data})
→ Future<void>
-
-
unregisterDeviceToken(String token)
→ Future<void>
-