DitoNotificationInfo class
Constructors
-
DitoNotificationInfo({required String id, required String notificationId, required String reference, required String title, required String message, required String link, required DateTime receivedAt, required bool isRead, String image = '', Map<
String, String> customData = const {}}) -
const
-
DitoNotificationInfo.fromMap(Map<
Object?, Object?> map) -
factory
Properties
-
customData
→ Map<
String, String> -
Custom data da campanha já decodificada; vazia quando não há custom data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- image → String
-
URL da imagem do push; vazio quando a campanha não tem imagem.
final
- isRead → bool
-
final
- link → String
-
final
- message → String
-
final
- notificationId → String
-
final
- receivedAt → DateTime
-
final
- reference → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited